==> eslint-plugin-angular-0.3.1.tgz: package/test/ng_directive_name.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var eslint = require('../node_modules/eslint/lib/eslint'),
    ESLintTester = require('eslint-tester');

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var eslintTester = new ESLintTester(eslint);
eslintTester.addRuleTest('rules/ng_directive_name', {
    valid: [{
        code: 'app.directive("eslintDirective", function(){});',
        args: [1, 'eslint']
    }, {
        code: 'app.directive("eslintDirective", function(){});',
        args: [1, /^eslint/]
    }, {
        code: 'app.directive("eslintDirective", function(){});',
        args: [1, undefined]
    }, {
        code: 'app.directive("eslintDirective", function(){});',
        args: [1, '/^eslint/']
    }],
    invalid: [
        {
            code: 'app.directive("Directive", function(){});',
            args: [1, 'eslint'],
            errors: [{ message: 'The Directive directive should be prefixed by eslint'}]
        },
        {
            code: 'app.directive("esLintDirective", function(){});',
            args: [1, 'eslint'],
            errors: [{ message: 'The esLintDirective directive should be prefixed by eslint'}]
        },
        {
            code: 'app.directive("Directive", function(){});',
            args: [1, /^eslint/],
            errors: [{ message: 'The Directive directive should follow this pattern: /^eslint/'}]
        }, {
            code: 'app.directive("Directive", function(){});',
            args: [1, '/^eslint/'],
            errors: [{ message: 'The Directive directive should follow this pattern: /^eslint/'}]
        }, {
            code: 'app.directive("ngDirective", []);',
            args: [1, /^eslint/],
            errors: [{ message: 'The ngDirective directive should not start with "ng". This is reserved for AngularJS directives'}]
        }
    ]
});

==> eslint-plugin-angular-0.5.0.tgz: package/test/ng_directive_name.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var rule = require('../rules/ng_directive_name'),
    RuleTester = require("eslint").RuleTester;

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var eslintTester = new RuleTester();
eslintTester.run('ng_directive_name', rule, {
    valid: [{
        code: 'app.directive("eslintDirective", function(){});',
        options: ['eslint'],
        settings: {angular: 1}
    }, {
        code: 'app.directive("eslintDirective", function(){});',
        options: [/^eslint/],
        settings: {angular: 1}
    }, {
        code: 'app.directive("eslintDirective", function(){});',
        options: [undefined],
        settings: {angular: 1}
    }, {
        code: 'app.directive("eslintDirective", function(){});',
        options: ['/^eslint/'],
        settings: {angular: 1}
    }, {
        code: 'app.directive("Directive", function(){});',
        options: ['eslint'],
        settings: {angular: 2}
    }],
    invalid: [
        {
            code: 'app.directive("Directive", function(){});',
            options: ['eslint'],
            errors: [{ message: 'The Directive directive should be prefixed by eslint'}]
        },
        {
            code: 'app.directive("esLintDirective", function(){});',
            options: ['eslint'],
            settings: {angular: 1},
            errors: [{ message: 'The esLintDirective directive should be prefixed by eslint'}]
        },
        {
            code: 'app.directive("Directive", function(){});',
            options: [/^eslint/],
            settings: {angular: 1},
            errors: [{ message: 'The Directive directive should follow this pattern: /^eslint/'}]
        }, {
            code: 'app.directive("Directive", function(){});',
            options: ['/^eslint/'],
            settings: {angular: 1},
            errors: [{ message: 'The Directive directive should follow this pattern: /^eslint/'}]
        }, {
            code: 'app.directive("ngDirective", []);',
            options: [/^eslint/],
            settings: {angular: 1},
            errors: [{ message: 'The ngDirective directive should not start with "ng". This is reserved for AngularJS directives'}]
        }
    ]
});
